@@ -52,6 +52,9 @@ class HumanReadableTextFormatting:
 
     @staticmethod
     def _longnum2string(x):
+        if x == 0:
+            return '0'
+
         units = ['', 'K', 'M', 'G', 'T', 'P']
         k = 1000.0
         magnitude = int(floor(log(x, k)))
@@ -81,7 +84,7 @@ class HumanReadableTextFormatting:
                 out_str += f'<br>{w}'
                 counter = 0
             else:
-                out_str += w
+                out_str += f' {w}'
 
         return out_str.strip()
 
@@ -136,7 +139,8 @@ def format_fig_layout(fig, fig_params):
         plot_bgcolor='#FFFFFF',
         font_family="'Roboto' sans-serif",
         bargap=0,  # bar graph sepcific updates
-        bargroupgap=0
+        bargroupgap=0,
+        hovermode=False
     )
 
     fig.update_annotations(font_size=fig_params['data_label_font_size'])
